@@ -87,7 +87,7 @@ valid_keys =     ['parent_dir', 'video_path', 'info_dir','info_directory', 'thum
                   'summary', 'seo_title', 'seo_description', 'seo_tags', 'thumbnail', 'duration_seconds',
                   'duration_formatted', 'captions_path', 'schema_markup', 'social_metadata', 'category',
                   'publication_date', 'file_metadata']
-
+logger = get_logFile(__name__)
 def create_key_value(json_obj, key, value):
     json_obj[key] = json_obj.get(key, value) or value
     return json_obj
@@ -137,12 +137,16 @@ def clean_text(text: str) -> str:
     text = text.strip()
     return text
 def get_frame_number(file_path):
+    if isinstance(file_path,dict):
+        file_path = file_path.get('frame')
+        
     file_path = '.'.join(file_path.split('.')[:-1])
     return int(file_path.split('_')[-1])
 def sort_frames(frames=None,directory=None):
     if frames in [None,[]] and directory and os.path.isdir(directory):
         frames = get_all_file_types(types=['image'],directory=directory)
     frames = frames or []
+    
     frames = sorted(
         frames,
         key=lambda x: get_frame_number(x) 
@@ -187,12 +191,12 @@ def update_sitemap(video_data,
     with open(sitemap_path, 'a') as f:
         f.write(f"""
 <url>
-    <loc>{video_data['canonical_url']}</loc>
+    <loc>{video_data.get('canonical_url')}</loc>
     <video:video>
-        <video:title>{video_data['seo_title']}</video:title>
-        <video:description>{video_data['seo_description']}</video:description>
-        <video:thumbnail_loc>{video_data['thumbnail']['file_path']}</video:thumbnail_loc>
-        <video:content_loc>{video_data['video_path']}</video:content_loc>
+        <video:title>{video_data.get('seo_title')}</video:title>
+        <video:description>{video_data.get('seo_description')}</video:description>
+        <video:thumbnail_loc>{video_data.get('thumbnail',{}).get('file_path',{})}</video:thumbnail_loc>
+        <video:content_loc>{video_data.get('video_path')}</video:content_loc>
     </video:video>
 </url>
 """)
@@ -212,12 +216,60 @@ def execute_if_bool(bool_key,function,keys,req=None,info_data=None):
         bool_response = info_data.get(bool_key) in [None,'',[],"",{}]
     logger.info(f"{bool_key} == {bool_response}")
     if bool_response:
-        info = function(**new_data)
-        print(info)
-        print(bool_key)
+        args, kwargs = prune_inputs(function, **new_data, flag=True)
+        info = function(*args, **kwargs)
+
         info_data = update_json_data(info_data,info,keys=True)
     safe_dump_to_file(data=info_data,file_path=get_video_info_path(**info_data))
     return info_data
+import inspect
+
+def prune_inputs(func, *args, **kwargs):
+    """
+    Adapt the provided args/kwargs to fit the signature of func.
+    Returns (args, kwargs) suitable for calling func.
+    """
+    sig = inspect.signature(func)
+    params = sig.parameters
+
+    # Handle positional arguments
+    new_args = []
+    args_iter = iter(args)
+    for name, param in params.items():
+        if param.kind in (inspect.Parameter.POSITIONAL_ONLY,
+                          inspect.Parameter.POSITIONAL_OR_KEYWORD):
+            try:
+                new_args.append(next(args_iter))
+            except StopIteration:
+                break
+        elif param.kind == inspect.Parameter.VAR_POSITIONAL:
+            # collect all remaining args
+            new_args.extend(args_iter)
+            break
+        else:
+            break
+
+    # Handle keyword arguments
+    new_kwargs = {}
+    for name, param in params.items():
+        if name in kwargs:
+            new_kwargs[name] = kwargs[name]
+        elif param.default is inspect.Parameter.empty and param.kind == inspect.Parameter.KEYWORD_ONLY:
+            # Required keyword not provided
+            raise TypeError(f"Missing required keyword argument: {name}")
+
+    # Only include keywords func accepts
+    accepted_names = {
+        name for name, p in params.items()
+        if p.kind in (inspect.Parameter.POSITIONAL_OR_KEYWORD,
+                      inspect.Parameter.KEYWORD_ONLY)
+    }
+    new_kwargs = {k: v for k, v in new_kwargs.items() if k in accepted_names}
+
+    return tuple(new_args), new_kwargs
+
+
+
 def generate_file_id(path: str, max_length: int = 50) -> str:
     base = os.path.splitext(os.path.basename(path))[0]
     base = unicodedata.normalize('NFKD', base).encode('ascii', 'ignore').decode('ascii')
@@ -229,7 +281,7 @@ def generate_file_id(path: str, max_length: int = 50) -> str:
         base = base[: max_length - len(h) - 1].rstrip('-') + '-' + h
     return base
 def get_video_id(**kwargs):
-    info_data = kwargs.get('info_data',kwargs)
+    info_data = kwargs.get('info_data',kwargs) or kwargs or {}
     info_dir = info_data.get('info_dir') or info_data.get('info_directory')
     video_id = info_data.get('video_id')
     video_path = info_data.get('video_path')
@@ -382,9 +434,7 @@ def get_key_vars(keys,req=None,data=None,info_data= None):
                 new_data[key] = get_video_info_dir(**all_data)
             elif key == 'base_url':
                 new_data[key] = DOMAIN
-            elif key == 'generator':
-                generator = get_generator()
-                new_data[key] = generator
+   
             elif key == 'LEDTokenizer':
                 new_data[key] = LEDTokenizer
             elif key == 'LEDForConditionalGeneration':
@@ -417,3 +467,4 @@ EXT_TO_PREFIX = {
     **dict.fromkeys({'.xls', '.xlsx', '.csv'}, 'sheets'),
     **dict.fromkeys({'.srt'}, 'srts'),
 }
+whisper_model_path = DEFAULT_PATHS["whisper"]
