@@ -101,7 +101,8 @@ def get_title_tags_description(title,keywords,summary,filename,title_length = No
     summary_length = summary_length or 150
     keyword_length = keyword_length or 3
     summary_desc = get_from_list(summary,length=summary_length)
-    seo_title = get_seo_title(title,keywords,title_length=title_length)
+    seo_title = get_seo_title(title,keywords,filename,title_length=title_length)
+    keywords_str = keywords
     if isinstance(keywords,list):
         keywords_str = ', '.join(get_from_list(keywords,length=keyword_length))
     seo_description = get_seo_description(summary_desc,keywords_str,keyword_length=keyword_length,desc_length=desc_length)
